@@ -179,8 +179,13 @@ mod timer;
 
 mod util;
 
-const SBI_SPEC_MAJOR: usize = 0;
-const SBI_SPEC_MINOR: usize = 3;
+#[cfg(feature = "guest")]
+mod guest;
+
+// pub mod instance; // TODO: SBI instances, useful for developing hypervisors
+
+const SBI_SPEC_MAJOR: usize = 1;
+const SBI_SPEC_MINOR: usize = 0;
 
 // RustSBI implementation ID: 4
 // Ref: https://github.com/riscv-non-isa/riscv-sbi-doc/pull/61
