@@ -100,7 +100,8 @@ impl<T: ?Sized> OnceFatBox<T> {
                 options(nostack)
             );
             // critical section begin
-            if (*self.thin_ptr.get()).is_null() { // not 'self.thin_ptr.get().is_null()'
+            if (*self.thin_ptr.get()).is_null() {
+                // not 'self.thin_ptr.get().is_null()'
                 *self.thin_ptr.get() = data_address;
                 *(self.meta.as_ptr() as *mut _) = ptr::metadata(fat_ptr);
                 ans = Ok(())
